from gdata import service
import gdata
import atom
import getopt
import sys
import os
from Blog import Blog, Post

class Blogger(Blog):

	def __init__(self, url, username, password, proxyEnable, host, port, proxyUsername, proxyPassword, blogType):
		"""Creates a GDataService and provides ClientLogin auth details to it.
		The email and password are required arguments for ClientLogin."""
		
		Blog.__init__(self, url, username, password, proxyEnable, host, port, proxyUsername, proxyPassword, blogType)
		self.post = Post()

		os.environ['http_proxy'] = ''
		os.environ['https_proxy'] = ''

		if proxyEnable == '1':
			if proxyUsername != '':
				os.environ['proxy-username'] = proxyUsername
				os.environ['proxy-password'] = proxyPassword
			
			os.environ['http_proxy'] = 'http://%s:%s' %(host, port)
			os.environ['https_proxy'] = 'https://%s:%s' %(host, port)

		self.post_id = 0
		self.loggedIn = False
		
		# Authenticate using ClientLogin.
		self.service = service.GDataService(username, password)
		self.service.source = 'GScribble'
		self.service.service = 'blogger'
		self.service.server = 'www.blogger.com'
		try:
			self.service.ProgrammaticLogin()

			# Get the blog ID for the first blog.
			feed = self.service.Get('/feeds/default/blogs')
			self_link = feed.entry[0].GetSelfLink()
			if self_link:
				self.blog_id = self_link.href.split('/')[-1]
	
			self.feed = self.service.GetFeed('/feeds/' + self.blog_id + '/posts/default')
			self.loggedIn = True
		except:
			pass

	def getCategories(self):
		self.postedCategory = []
		if not self.loggedIn:
			return False
		try:
			for entry in self.feed.entry:
				for category in entry.category:
					if category.term not in self.postedCategory:
						self.postedCategory.append(category.term)
				
			return True
		except:
			return False

	def getRecentPosts(self):
		if not self.loggedIn:
			return False

		try:
			self.posts = []
			if self.post_id != 0:
				self.feed = self.service.GetFeed('/feeds/' + self.blog_id + '/posts/default')

			for entry in self.feed.entry:
				if entry.title.text:
					self.posts.append({'title' : entry.title.text})
			return True
		except:
			return False

	def getPost(self, title):
		if not self.loggedIn:
			return False

		try:	
			p = Post()
			cat = []
			for entry in self.feed.entry:
				if entry.title.text == title:
					#setting post_id to track the post
					self.post_id = entry.id.text 
					self_id = entry.id.text 
					tokens = self_id.split("-")
					self.post.postId = tokens[-1]
					
					p.title = entry.title.text
					p.body = entry.content.text
					for category in entry.category:
						cat.append(category.term)
					p.category = cat
					
			return p
		except:
			return False

	def newPost(self, blogPost):
		'''Create a new post'''
		if not self.loggedIn:
			return False

		entry = gdata.GDataEntry()
		entry.title = atom.Title(title_type='xhtml', text = blogPost['title'])
		entry.content = atom.Content(content_type='html', text = blogPost['description'])
		for c in blogPost['categories']:
			entry.category.append(atom.Category(scheme='http://www.blogger.com/atom/ns#', term = c))
		
		control = atom.Control()
		control.draft = atom.Draft(text='yes')
		entry.control = control
		# Ask the service to insert the new entry.
		p = self.service.Post(entry, '/feeds/' + self.blog_id + '/posts/default')
		# track the long blogger post id
		self.post_id = p.id.text 
		tokens = self.post_id.split("-")
		self.post.postId = tokens[-1]
		return True
		#except:
		#	print "here"

	def publishPost(self):
		'''Publishes a posted content'''
		if not self.loggedIn:
			return False
		try:
			for entry in self.feed.entry:
				if entry.id.text == self.post_id:
					control = atom.Control()
					control.draft = atom.Draft(text='no')
					entry.control = control
					self.service.Put(entry, entry.GetEditLink().href)
			self.post.isPublished = 1
			return True
		except:
			return False

	def editPost(self, blogPost):
		if not self.loggedIn:
			return False
		try:
			for entry in self.feed.entry:
				if entry.id.text == self.post_id:
					entry.title = atom.Title(title_type='xhtml', text = blogPost['title'])
					entry.content = atom.Content(content_type='html', text = blogPost['description'])
					for c in blogPost['categories']:
						entry.category.append(atom.Category(scheme='http://www.blogger.com/atom/ns#', term = c))					
					r = self.service.Put(entry, entry.GetEditLink().href)
			return True
		except:
			return False
